@@ -10,11 +10,11 @@ selectDif<-function (Data, group, focal.name, method, anchor = NULL, props = NUL
         focal.name = focal.name, anchor = anchor, props = props, 
         thrTID = thrTID, purify = purify, nrIter = nrIter, save.output = save.output, 
         output = output), MH = difMH(Data = Data, group = group, 
-        focal.name = focal.name, anchor = anchor, MHstat = MHstat, 
+        focal.name = focal.name, match=match, anchor = anchor, MHstat = MHstat, 
         correct = correct, exact = exact, alpha = alpha, purify = purify, 
         nrIter = nrIter, p.adjust.method = p.adjust.method, save.output = save.output, output = output), 
         Std = difStd(Data = Data, group = group, focal.name = focal.name, 
-            anchor = anchor, stdWeight = stdWeight, thrSTD = thrSTD, 
+            anchor = anchor, match=match, stdWeight = stdWeight, thrSTD = thrSTD, 
             purify = purify, nrIter = nrIter, save.output = save.output, 
             output = output), Logistic = difLogistic(Data = Data, 
             group = group, focal.name = focal.name, anchor = anchor, 
@@ -22,7 +22,7 @@ selectDif<-function (Data, group, focal.name, method, anchor = NULL, props = NUL
             criterion = criterion, alpha = alpha, purify = purify, 
             nrIter = nrIter, p.adjust.method = p.adjust.method, save.output = save.output, output = output), 
         BD = difBD(Data = Data, group = group, focal.name = focal.name, 
-            anchor = anchor, BDstat = BDstat, alpha = alpha, 
+            anchor = anchor, match=match, BDstat = BDstat, alpha = alpha, 
             purify = purify, nrIter = nrIter,p.adjust.method = p.adjust.method,  save.output = save.output, 
             output = output), LRT = difLRT(Data = Data, group = group, 
             focal.name = focal.name, alpha = alpha, purify = purify, 
